Skip to contents

Generate MCD dataset (Medicare Consumer Directory)

Usage

generate_mcd(
  spine = NULL,
  seed = 42L,
  output_dir = NULL,
  format = c("parquet", "csv"),
  return_data = FALSE
)

Arguments

spine

Data.frame from generate_spine() or NULL. If NULL, the spine is loaded from the active run directory.

seed

Integer. Random seed.

output_dir

Character or NULL. Base output directory. If NULL, uses get_data_path().

format

Character. Currently parquet only. Passing "csv" is accepted by the argument matcher but rejected at runtime.

return_data

Logical. If TRUE, returns generated data.frames in addition to writing parquet.

Dataset and variable information

The ABS PLIDA data and legislation website gives information about this dataset. Use dataset_info("MCD") for dataset information. Use variable_info("MCD") for variables, sources, value support, and topic tags.