Skip to contents

Generate RPS dataset (Rental Property Schedule)

Usage

generate_rps(
  spine = NULL,
  seed = 42L,
  years = 2000L:2023L,
  output_dir = NULL,
  format = c("parquet", "csv"),
  return_data = FALSE
)

Arguments

spine

Data.frame from generate_spine() or NULL. If NULL, the spine is loaded from the active run directory.

seed

Integer. Random seed.

years

Integer vector. Financial years to generate.

output_dir

Character or NULL. Base output directory. If NULL, uses get_data_path().

format

Character. Currently parquet only. Passing "csv" is accepted by the argument matcher but rejected at runtime.

return_data

Logical. If TRUE, returns generated data.frames in addition to writing parquet.

Dataset and variable information

The ATO residential rental properties website gives information about this dataset. Use dataset_info("RPS") for dataset information. Use variable_info("RPS") for variables, sources, value support, and topic tags.