Skip to contents

Generate VISA dataset (Visa Applications and Grants)

Usage

generate_visa(
  spine = NULL,
  seed = 42L,
  output_dir = NULL,
  format = c("parquet", "csv"),
  return_data = FALSE,
  years = 1990L:2026L
)

Arguments

spine

Data.frame from generate_spine() or NULL. If NULL, the spine is loaded from the active run directory.

seed

Integer. Random seed.

output_dir

Character or NULL. Base output directory. If NULL, uses get_data_path().

format

Character. Currently parquet only. Passing "csv" is accepted by the argument matcher but rejected at runtime.

return_data

Logical. If TRUE, returns generated data.frames in addition to writing parquet.

years

Integer vector. Application and grant observation years.

Dataset and variable information

The Home Affairs visa statistics website gives information about this dataset. Use dataset_info("VISA") for dataset information. Use variable_info("VISA") for variables, sources, value support, and topic tags.