Generate AEDC dataset (Australian Early Development Census)
Source:R/generate_aedc.R
generate_aedc.RdGenerate AEDC dataset (Australian Early Development Census)
Arguments
- spine
Data.frame from
generate_spine()or NULL. If NULL, the spine is loaded from the active run directory.- seed
Integer. Random seed.
- cycles
Integer vector. AEDC cycle years to generate.
- output_dir
Character or NULL. Base output directory. If NULL, uses
get_data_path().- format
Character. Currently parquet only. Passing
"csv"is accepted by the argument matcher but rejected at runtime.- return_data
Logical. If TRUE, returns generated data.frames in addition to writing parquet.
Dataset and variable information
The Department of Education AEDC
website gives information about this dataset. Use dataset_info("AEDC") for
dataset information. Use variable_info("AEDC") for variables, sources,
value support, and topic tags.