Sets the directory where fplida stores generated data (spine, dataset CSVs,
agency spine files). The path is persisted across R sessions by writing to
~/.Renviron.
Sets the directory where fplida stores generated data (spine, dataset CSVs,
agency spine files). The path is persisted across R sessions by writing to
~/.Renviron.